/*-----------------------------------------------------------------------
dreams_figure1.do

Stata do file to replicate figures 1 and B.1 of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

* loop to create 3 panels for different parameter sets
forvalues pset = 1(1)3 {
	* set parameter values
	* appendix figure b1 panel a
	if `pset' == 1 {
		local eB = 0.40
		local eS = 0.24
		local OmegaB = 0.95
		local OmegaS = 0.21
		local pi2 = 3.08 
		local Dgamma = 0.30		
	}
	* appendix figure b1 panel b
	else if `pset' == 3 {
		local eB = 0.50
		local eS = 0.24
		local OmegaB = 0.70
		local OmegaS = 0.04
		local pi2 = 2.75 
		local Dgamma = 0.30		
	}
	* figure 1
	else {
		local eB = 0.80
		local eS = 0.70
		local OmegaB = 0.50
		local OmegaS = 0.45
		local pi2 = 10.8
		local Dgamma = 0.30		
	}
	display "Paremeter values:"
	display "eB = " `eB'
	display "eS = " `eS'
	display "ΩB = " `OmegaB'
	display "ΩS = " `OmegaB'
	display "π2 = " `pi2'
	display "Δγ = " `Dgamma'
	* calculate  and display thresholds
	local De = `eB' - `eS'
	local DOmega = `OmegaB' - `OmegaS'
	local aBSSS = `Dgamma' / (`De' * `OmegaS' * `pi2')
	local aBBBS = `Dgamma' / (`eB' * `DOmega' * `pi2')
	local aSBSS = `Dgamma' / (`eS' * `DOmega' * `pi2')
	local aBBSB = `Dgamma' / (`De' * `OmegaB' * `pi2')
	local aBBSS = 2 * `Dgamma' / ((`OmegaB' * `eB' - `OmegaS' * `eS') * `pi2')
	display "Thresholds:"
	display "αBS≻SS ≡ Δγ / (Δe ΩS π2) = " `aBSSS'
	display "αBB≻BS ≡ Δγ / (eB ΔΩ π2) = " `aBBBS'
	display "αSB≻SS ≡ Δγ / (eS ΔΩ π2) = " `aSBSS'
	display "αBB≻SB ≡ Δγ / (Δe ΩB π2) = " `aBBSB'
	display "αBB≻SS ≡ 2Δγ / ((ΩB eB − ΩS eS) π2) = " `aBBSS'
	* determine case (1/2/3) as per proposition 1
	if `De'/`DOmega' < `eS'/`OmegaB'{
		local case = 1
	}
	else if `eB'/`OmegaS' < `De'/`DOmega'{
		local case = 3
	}
	else {
		local case = 2
	}
	* produce figure according to case
	if `case' == 1{
		local xline = `aBBSB'
		local xlabels = `"`aBBBS' "{&alpha}{subscript:BB{&gt}BS}" `aSBSS' "{&alpha}{subscript:SB{&gt}SS}" `aBBSB' "{&alpha}{subscript:BB{&gt}SB}" "'
		local filename = "figb1a"
	}
	else if `case' == 3{
		local xline = `aBSSS'
		local xlabels = `"`aBSSS' "{&alpha}{subscript:BS{&gt}SS}" `aBBBS' "{&alpha}{subscript:BB{&gt}BS}" `aSBSS' "{&alpha}{subscript:SB{&gt}SS}" "'
		local filename = "figb1b"
	}
	else if `case' == 2 {
		local xline = `aBBSS'
		local xlabels = `"`aBBBS' "{&alpha}{subscript:BB{&gt}BS}" `aBBSS' "{&alpha}{subscript:BB{&gt}SS}" `aSBSS' "{&alpha}{subscript:SB{&gt}SS}" "'
		local filename = "fig1"
	}
	drop _all
	set obs 4
	generate x = .
	replace x = 0 in 1
	replace x = `xline' in 2
	replace x = 1 in 3
	
	* lines
	generate line45 = .
	replace line45 = 0 in 1
	replace line45 = 1 in 3
	
	generate lineSSSB =.
	replace lineSSSB = `aSBSS' in 1
	replace lineSSSB = `aSBSS' in 2
	
	generate lineBSBB = .
	replace lineBSBB = `aBBBS' in 2
	replace lineBSBB = `aBBBS' in 3
	
	* labels
	generate scatterlabel = ""
	replace scatterlabel = "SB" in 1
	replace scatterlabel = "BB" in 2
	replace scatterlabel = "SS" in 3
	replace scatterlabel = "BS" in 4
	
	generate scatterx = .
	replace scatterx = `xline'/2 in 1
	replace scatterx = (1+`xline')/2 in 2
	replace scatterx = `xline'/2 in 3
	replace scatterx = (1+`xline')/2 in 4
	
	generate scattery = .
	replace scattery = (1+`aSBSS')/2 in 1
	replace scattery = (1+`aBBBS')/2 +0.05 in 2
	replace scattery = `aSBSS'/2 in 3
	replace scattery = `aBBBS'/2 in 4
	
	* shades
	gen low1 = .
	replace low1 = `xline' in 1
	replace low1 = `xline' in 2
	
	gen high1 =.
	replace high1 = 1 in 1
	replace high1 = 1 in 2
	
	gen low2 = .
	replace low2 = 0 in 2
	replace low2 = 0 in 3
	
	gen high2 =.
	replace high2 = `xline' in 2
	replace high2 = `xline' in 3

	* graphs
	twoway (rarea low1 high1 x,  sort color(gs14)) ///
	(rarea low2 high2 x,  sort color(gs14)) ///
	(line line45 x, lcolor(black) lpattern(dash) lwidth(thin)) ///
	(line lineSSSB x, lcolor(black) lpattern(solid) lwidth(thin)) ///
	(line lineBSBB x, lcolor(black) lpattern(solid) lwidth(thin)) ///
	(scatter scattery scatterx, mcolor(none) msize(zero) mlabel(scatterlabel) mlabposition(0) mlabsize(large) mlabcolor(dknavy)), ///
	yscale(range(0 1)) xscale(range(0 1)) ytitle("{&alpha}", orient(horizontal)) xtitle("{&sigma}") plotregion(margin(zero)) ///
	xlabel(0 1 `xlabels', format(%12.0fc) angle(0)) ylabel(0 1 `xlabels', format(%12.0fc) angle(0)) ///
	xline(`xline', lcolor(black) lpattern(solid) lwidth(thin) noextend) ///
	yline(`xline', lcolor(black) lpattern(dash) lwidth(thin) noextend) ///
	xline(1, lcolor(black) lpattern(solid) lwidth(thin) noextend) ///
	yline(1, lcolor(black) lpattern(solid) lwidth(thin) noextend)
	
		*(rarea)
	*(contour contourz contourx contoury, heatmap clegend(off) crule(intensity) scolor(240 255 255) ecolor(210 255 255)), ///
	
	graph export ../../results/dreams_`filename'.png, as(png) replace
	graph export ../../results/dreams_`filename'.eps, as(eps) replace
}

