/*-----------------------------------------------------------------------
dreams_text_results.do

Stata do file to produce numbers mentioned in the text of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

* read panel
use ../../data/processed/nlsy_panel_sample, clear
sort person_id year

* location of individuals at age 40
preserve
keep if age > 39 & age < 41
keep if (!missing(cbsa) & !missing(cbsa_at14)) /*
*/ | ( (missing(cbsa) | missing(cbsa_at14)) & (!missing(fips) & !missing(fips_at14)) )
* cbsa/county at age 14 matches county at age 40 (all workers)
count
local tr_nt `r(N)'
count if (cbsa == cbsa_at14 & !missing(cbsa) & !missing(cbsa_at14))/*
*/  | (fips == fips_at14 & (missing(cbsa) | missing(cbsa_at14)))
local tr_n `r(N)'
local tr_40as14all : di %-2.0fc round(100 * `tr_n' / `tr_nt')
* cbsa/county at age 14 matches county at age 40 (workers with college education)
keep if educ_highest_life >= 16 & !missing(educ_highest_life)
count
local tr_nt `r(N)'
count if (cbsa == cbsa_at14 & !missing(cbsa) & !missing(cbsa_at14))/*
*/  | (fips == fips_at14 & (missing(cbsa) | missing(cbsa_at14)))
local tr_n `r(N)'
local tr_40as14ced : di %-2.0fc round(100 * `tr_n' / `tr_nt')
restore

* correlation between ability and self-confidence (all workers)
preserve
pwcorr afqt_pctl self_pctl
local tr_corr_as_all : di %4.2fc round(`r(rho)',0.01)
* correlation between ability and self-confidence (workers with college education)
keep if educ_highest_life >= 16 & !missing(educ_highest_life)
pwcorr afqt_pctl self_pctl
local tr_corr_as_ced : di %4.2fc round(`r(rho)',0.01)
restore

* median age in 1980
preserve
keep if year == 1980
sum age, detail
local tr_age_1980_min : di %2.0fc round(`r(min)')
local tr_age_1980_max : di %2.0fc round(`r(max)')
local tr_age_1980_p50 : di %2.0fc round(`r(p50)')
restore

* median age in junior period, by education
preserve
keep if junior_period == 1
summ age if educ_highest_life <= 12, detail
local tr_age_junior_p50hs : di %2.0fc round(`r(p50)')
summ age if educ_highest_life >= 16, detail
local tr_age_junior_p50ced : di %2.0fc round(`r(p50)')
restore

* percentage in big cities
preserve
gen big = 0
replace big = 1 if (cbsa_pop2010 >= $size_big) & !missing(cbsa_pop2010)
keep if junior_period == 1 | senior_period == 1
count if junior_period == 1
local tr_nt `r(N)'
count if junior_period == 1 & big == 1
local tr_n `r(N)'
local tr_big_j : di %-2.0fc round(100 * `tr_n' / `tr_nt')
count if senior_period == 1
local tr_nt `r(N)'
count if senior_period == 1 & big == 1
local tr_n `r(N)'
local tr_big_s : di %-2.0fc round(100 * `tr_n' / `tr_nt')
restore

* location of individuals in junior period
preserve
* cbsa/county in junior period matches county at age 14
keep if !missing(cbsa_junior_sameas_at14)
count
local tr_nt `r(N)'
count if cbsa_junior_sameas_at14
local tr_n `r(N)'
local tr_junas14 : di %-2.0fc round(100 * `tr_n' / `tr_nt')
restore
preserve
* cbsa/county in junior period matches county at age 40
gen cbsa_jun = cbsa if junior_period == 1
gen fips_jun = fips if junior_period == 1
egen cbsa_junior = max(cbsa_jun), by (person_id)
egen fips_junior = max(fips_jun), by (person_id)
keep if age > 39 & age < 41
gen cbsa_at40 = cbsa
gen fips_at40 = fips
gen cbsa_junior_sameas_at40 = 1 if cbsa_junior == cbsa_at40 & !missing(cbsa_junior)
replace cbsa_junior_sameas_at40 = 1 if fips_junior == fips_at40 & !missing(fips_junior) & missing(cbsa_junior_sameas_at40)
replace cbsa_junior_sameas_at40 = 0 if missing(cbsa_junior_sameas_at40) & !missing(fips_at40)
keep if !missing(cbsa_junior_sameas_at40)
count
local tr_nt `r(N)'
count if cbsa_junior_sameas_at40
local tr_n `r(N)'
local tr_junas40 : di %-2.0fc round(100 * `tr_n' / `tr_nt')
restore

* migration between junior and senior periods
preserve
keep if junior_period == 1 | senior_period == 1
gen big = 0
replace big = 1 if (cbsa_pop2010 >= $size_big) & !missing(cbsa_pop2010)
gen cbsa_j = cbsa if junior_period == 1
gen fips_j = fips if junior_period == 1
gen cbsa_s = cbsa if senior_period == 1
gen fips_s = fips if senior_period == 1
gen big_j = 0 if junior_period == 1
replace big_j = 1 if big == 1 & junior_period == 1
gen big_s = 0 if senior_period == 1
replace big_s = 1 if big == 1 & senior_period == 1
collapse (min) cbsa_j cbsa_s fips_j fips_s big_j big_s, by (person_id)
keep if (!missing(cbsa_j) & !missing(cbsa_s)) /*
*/ | ( (missing(cbsa_j) | missing(cbsa_s)) & (!missing(fips_j) & !missing(fips_s)) )
count
local tr_nt `r(N)'
count if (cbsa_j != cbsa_s & !missing(cbsa_j) & !missing(cbsa_s))/*
*/  | (fips_j != fips_s & (missing(cbsa_j) | missing(cbsa_s)))
local tr_n `r(N)'
local tr_mig_js : di %-4.1fc round(100 * `tr_n' / `tr_nt', 0.01)
count if ((cbsa_j != cbsa_s & !missing(cbsa_j) & !missing(cbsa_s))/*
*/  | (fips_j != fips_s & (missing(cbsa_j) | missing(cbsa_s))))/*
*/  & (big_j != big_s)
local tr_n `r(N)'
local tr_mig_bs__js : di %-4.1fc round(100 * `tr_n' / `tr_nt', 0.01)
restore

* sample size
use ../../data/processed/nlsy_panel, clear
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_all : di %5.0fc round(`r(N)')
drop one
* drop if afqt or 1980 self-confidence score are missing
drop if missing(afqt_80) | missing(self_80_zpctl)
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_afqtself : di %5.0fc round(`r(N)')
drop one
* count observations with junior period location
merge 1:1 person_id year using ../../data/processed/nlsy_panel_sample, keepusing(junior_period senior_period)
preserve
egen max = max(junior_period), by (person_id)
drop if missing(max)
drop max
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_junior : di %5.0fc round(`r(N)')
drop one
restore
* count observations with junior period location
preserve
egen max = max(senior_period), by (person_id)
drop if missing(max)
drop max
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_senior : di %5.0fc round(`r(N)')
drop one
restore
* demographic controls available
use ../../data/processed/nlsy_panel_sample, clear
preserve
egen miss = rowmiss(junior_period self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft birth_year cbsa_at14_small)
drop if miss > 0
drop miss
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_demog_j : di %5.0fc round(`r(N)')
drop one
restore
preserve
egen miss = rowmiss(senior_period self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft)
drop if miss > 0
drop miss
bysort person_id: gen one = 1 if _n==1
sum one, meanonly
local tr_obs_demog_s : di %5.0fc round(`r(N)')
drop one
restore

* output numbers given in the text to text file
file open txtfile using ../../results/density_text_results.txt, write replace
file write txtfile "'City of dreams', by Jorge De la Roca, Gianmarco I. P. Ottaviano, and Diego Puga" _n
file write txtfile _n
file write txtfile "Results mentioned in the text not contained in tables." _n
file write txtfile _n
file write txtfile "Section 1" _n
file write txtfile _n
file write txtfile "According to our data, `tr_40as14all'% of all individuals (and `tr_40as14ced'% of the college-educated)" _n
file write txtfile "in the United States live in the same city at ages 14 and 40." _n
file write txtfile _n
file write txtfile "Our data show a low correlation of `tr_corr_as_all' between ability and self-confidence (our" _n
file write txtfile "measure of ability self-assessment). Among college graduates, this correlation" _n
file write txtfile "falls to `tr_corr_as_ced'." _n
file write txtfile _n
file write txtfile "Our primary measure of ability is the individual's percentile score in the" _n
file write txtfile "Armed Forces Qualification Test (AFQT), a general ability test administered to" _n
file write txtfile "respondents in 1980 when they were between `tr_age_1980_min' and `tr_age_1980_max' (with a median age of `tr_age_1980_p50')." _n
file write txtfile _n
file write txtfile "Section 3" _n
file write txtfile _n
file write txtfile "Our measure of ability is the individual's percentile score in the Armed Forces" _n
file write txtfile "Qualification Test (AFQT). This general ability test was administered in 1980" _n
file write txtfile "when NLSY respondents were between `tr_age_1980_min' and `tr_age_1980_max' (with a median age of `tr_age_1980_p50')," _n
file write txtfile "regardless of their interest in the military." _n
file write txtfile _n
file write txtfile "The correlation between the AFQT and the Rosenberg test scores is low (`tr_corr_as_all')" _n
file write txtfile "for the full sample, suggesting that ability assessment is imperfect. Our model" _n
file write txtfile "assumes that labour market experience provides workers with a better" _n
file write txtfile "self-assessment of ability. Since the age of NLSY79 respondents ranged between" _n
file write txtfile "`tr_age_1980_min' and `tr_age_1980_max' when tested in 1980, a way to see if self-assessment improves over" _n
file write txtfile "time with job experience is to analyse whether self-confidence and ability are" _n
file write txtfile "more correlated for older respondents at the time of the tests." _n
file write txtfile _n
file write txtfile "Regarding timing, we set the junior period for all respondents at the year after" _n
file write txtfile "their highest level of education is completed, excluding educational periods" _n
file write txtfile "that happen after more than two years away from education (median age of `tr_age_junior_p50hs' for" _n
file write txtfile "individuals without post-secondary education and `tr_age_junior_p50ced' for the college-educated)." _n
file write txtfile _n
file write txtfile "Based on these counties, we determine whether each respondent lives in a Core" _n
file write txtfile "Based Statistical Areas (CBSA) with a 2010 population above two million. If so," _n
file write txtfile "we classify them as living in a big city, otherwise as living in a small city." _n
file write txtfile "This population threshold leads to `tr_big_j'% and `tr_big_s'% of individuals living in big" _n
file write txtfile "cities during their junior and senior periods respectively." _n
file write txtfile _n
file write txtfile "The initial sample includes all `tr_obs_all' individuals in the cross-sectional sample" _n
file write txtfile "of the NLSY79. We exclude individuals for whom the AFQT or the Rosenberg" _n
file write txtfile "self-esteem scores are missing, which reduces the sample to `tr_obs_afqtself' individuals." _n
file write txtfile "We can determine the junior period location of `tr_obs_junior' of these individuals and," _n
file write txtfile "due to sampling attrition, the senior period locations of `tr_obs_senior' of them. The" _n
file write txtfile "availability of the demographic controls that we include further reduces our" _n
file write txtfile "sample to `tr_obs_demog_j' individuals in the junior period analysis and 4,985 individuals" _n
file write txtfile "in the senior period analysis." _n
file write txtfile _n
file write txtfile "Section 6" _n
file write txtfile _n
file write txtfile "One year after completing their education, `tr_junas14'% of individuals in our sample are" _n
file write txtfile "in the same city as at age 14, and `tr_junas40'% remain there by age 40." _n
file write txtfile _n
file write txtfile "In table 2, `tr_mig_js'% of individuals move between both periods while only 13.4%" _n
file write txtfile "change city-size class (i.e, SB or BS)." _n
file write txtfile _n
file write txtfile "Importantly, self-assessment of ability relative to people with the same" _n
file write txtfile "education is so imperfect that there is virtually no correlation (`tr_corr_as_ced') between" _n
file write txtfile "self-confidence and ability among college-educated workers." _n
file close txtfile
view ../../results/density_text_results.txt


